@@ -3,10 +3,12 @@
 
 from __future__ import absolute_import  # noreorder
 
+import glob
 import io
 import math
 import os
 import re
+import shutil
 
 from pyaedt.application.AnalysisNexxim import FieldAnalysisCircuit
 from pyaedt.generic import ibis_reader
@@ -1431,6 +1433,98 @@ class Circuit(FieldAnalysisCircuit, object):
 
         return True
 
+    @pyaedt_function_handler()
+    def assign_voltage_frequency_dependent_excitation_to_ports(self, ports, filepath):
+        """Assign a frequency dependent excitation to circuit ports from a frequency dependent source (.fds format).
+
+        Parameters
+        ----------
+        ports : list
+            List of circuit ports to assign to the frequency dependent excitation.
+        filepath : str
+            Path to the frequency dependent file.
+
+        Returns
+        -------
+        bool
+            ``True`` when successful, ``False`` when failed.
+
+        References
+        ----------
+
+        >>> oDesign.UpdateSources
+        """
+        if not os.path.exists(filepath) or os.path.splitext(filepath)[1] != ".fds":
+            self.logger.error("Introduced file is not correct. Check path and format.")
+            return False
+
+        if not all(elem in self.modeler.schematic.nets for elem in ports):
+            self.logger.error("Defined ports do not exist")
+            return False
+
+        id = self.modeler.schematic.create_unique_id()
+
+        arg1 = [
+            "NAME:NexximSources",
+            [
+                "NAME:NexximSources",
+                [
+                    "NAME:Data",
+                    [
+                        "NAME:VoltageSourceFreq" + str(id),
+                        "DataId:=",
+                        "Source" + str(id),
+                        "Type:=",
+                        17,
+                        "Output:=",
+                        0,
+                        "NumPins:=",
+                        2,
+                        "Netlist:=",
+                        "V@ID %0 %1 *FreqDependentSourceData(@FreqDependentSourceData)",
+                        "CompName:=",
+                        "Nexxim Circuit Elements\\Independent Sources:V_PWL_F",
+                        "FDSFileName:=",
+                        'voltage_source_file="' + filepath + '"',
+                        [
+                            "NAME:Properties",
+                            "TextProp:=",
+                            ["LabelID", "HD", "Property string for netlist ID", "V@ID"],
+                            "ButtonProp:=",
+                            [
+                                "FreqDependentSourceData",
+                                "OD",
+                                "Frequency Dependent Source Data",
+                                'voltage_source_file="' + filepath + '"',
+                                'voltage_source_file="' + filepath + '"',
+                                7,
+                                "ButtonPropClientData:=",
+                                [],
+                            ],
+                            "TextProp:=",
+                            ["COMPONENT", "RHD", "", "vsource_freq"],
+                            "ButtonProp:=",
+                            ["CosimDefinition", "SOD", "", "Edit", "Edit", 0, "ButtonPropClientData:=", []],
+                            "MenuProp:=",
+                            ["CoSimulator", "D", "", "DefaultNetlist", 0],
+                        ],
+                    ],
+                ],
+            ],
+        ]
+
+        arg2 = ["NAME:ComponentConfigurationData"]
+
+        arg3 = ["NAME:ComponentConfigurationData", ["NAME:EnabledPorts", "VoltageSourceFreq" + str(id) + ":=", ports]]
+
+        arg2.append(arg3)
+        try:
+            self.odesign.UpdateSources(arg1, arg2)
+        except:
+            self.logger.error("Voltage Source not updated, incorrect file.")
+            return False
+        return True
+
     @pyaedt_function_handler()
     def set_differential_pair(
         self,
@@ -1630,3 +1724,45 @@ class Circuit(FieldAnalysisCircuit, object):
             ["NAME:DataBlock", "name:=", datablock_name, "filename:=", netlist_file, "filelocation:=", 0]
         )
         return True
+
+    @pyaedt_function_handler()
+    def browse_log_file(self, filepath=None):
+        """Save most recent log file into a new directory.
+
+        Parameters
+        ----------
+        filepath : str, optional
+            New log file path. The default is the pyaedt folder.
+
+        Returns
+        -------
+        str
+            File Path
+        """
+        if filepath and not os.path.exists(os.path.normpath(filepath)):
+            self.logger.error("Path does not exist.")
+            return None
+        elif not filepath:
+            filepath = os.path.join(os.path.normpath(self.working_directory), "logfile")
+            if not os.path.exists(filepath):
+                os.mkdir(filepath)
+
+        results_path = os.path.join(os.path.normpath(self.results_directory), self.design_name)
+        results_temp_path = os.path.join(results_path, "temp")
+
+        # Check if .log exist in temp folder
+        if os.path.exists(results_temp_path) and glob.glob(os.path.join(results_temp_path, "*.log")):
+            # Check the most recent
+            files = glob.glob(os.path.join(results_temp_path, "*.log"))
+            latest_file = max(files, key=os.path.getctime)
+        elif os.path.exists(results_path) and glob.glob(os.path.join(results_path, "*.log")):
+            # Check the most recent
+            files = glob.glob(os.path.join(results_path, "*.log"))
+            latest_file = max(files, key=os.path.getctime)
+        else:
+            self.logger.error("Design not solved")
+            return None
+
+        shutil.copy(latest_file, filepath)
+        filename = os.path.basename(latest_file)
+        return os.path.join(filepath, filename)
