@@ -56,11 +56,6 @@ class EdbPadstacks(object):
         """Db object."""
         return self._pedb.db
 
-    @property
-    def _padstack_methods(self):
-        """ """
-        return self._pedb.edblib.Layout.PadStackMethods
-
     @property
     def _logger(self):
         """ """
@@ -248,15 +243,73 @@ class EdbPadstacks(object):
         str
             Name of the padstack if the operation is successful.
         """
-        pad = self._padstack_methods.CreateCircularPadStackDef(
-            self._builder,
-            padstackname,
-            holediam,
-            paddiam,
-            antipaddiam,
-            startlayer,
-            endlayer,
+
+        PadStack = self._edb.Definition.PadstackDef.Create(self._active_layout.GetCell().GetDatabase(), padstackname)
+        new_PadStackData = self._edb.Definition.PadstackDefData.Create()
+        list_values = convert_py_list_to_net_list(
+            [self._get_edb_value(holediam), self._get_edb_value(paddiam), self._get_edb_value(antipaddiam)]
         )
+        value0 = self._get_edb_value(0.0)
+        new_PadStackData.SetHoleParameters(
+            self._edb.Definition.PadGeometryType.Circle,
+            list_values,
+            value0,
+            value0,
+            value0,
+        )
+        new_PadStackData.SetHoleRange(self._edb.Definition.PadstackHoleRange.UpperPadToLowerPad)
+        layers = list(self._pedb.core_stackup.signal_layers.keys())
+        if not startlayer:
+            startlayer = layers[0]
+        if not endlayer:
+            endlayer = layers[len(layers) - 1]
+
+        antipad_shape = self._edb.Definition.PadGeometryType.Circle
+        started = False
+        new_PadStackData.SetPadParameters(
+            "Default",
+            self._edb.Definition.PadType.RegularPad,
+            self._edb.Definition.PadGeometryType.Circle,
+            convert_py_list_to_net_list([self._get_edb_value(paddiam)]),
+            value0,
+            value0,
+            value0,
+        )
+
+        new_PadStackData.SetPadParameters(
+            "Default",
+            self._edb.Definition.PadType.AntiPad,
+            antipad_shape,
+            convert_py_list_to_net_list([self._get_edb_value(antipaddiam)]),
+            value0,
+            value0,
+            value0,
+        )
+        for layer in layers:
+            if layer == startlayer:
+                started = True
+            if layer == endlayer:
+                started = False
+            if started:
+                new_PadStackData.SetPadParameters(
+                    layer,
+                    self._edb.Definition.PadType.RegularPad,
+                    self._edb.Definition.PadGeometryType.Circle,
+                    convert_py_list_to_net_list([self._get_edb_value(paddiam)]),
+                    value0,
+                    value0,
+                    value0,
+                )
+                new_PadStackData.SetPadParameters(
+                    layer,
+                    self._edb.Definition.PadType.AntiPad,
+                    antipad_shape,
+                    convert_py_list_to_net_list([self._get_edb_value(antipaddiam)]),
+                    value0,
+                    value0,
+                    value0,
+                )
+        PadStack.SetData(new_PadStackData)
         self.update_padstacks()
 
     @pyaedt_function_handler()
@@ -366,10 +419,24 @@ class EdbPadstacks(object):
             ``False`` is returned if the net does not belong to the component.
 
         """
-        if self._builder:
-            pinlist = self._padstack_methods.GetPinsFromComponentAndNets(self._active_layout, refdes, netname)
-            if pinlist.Item1:
-                return pinlist.Item2
+        pinlist = []
+        if refdes:
+            if refdes in self._pedb.core_components.components:
+                if netname:
+                    for pin, val in self._pedb.core_components.components[refdes].pins.items():
+                        if val.net_name == netname:
+                            pinlist.append(val)
+                else:
+                    for pin in self._pedb.core_components.components[refdes].pins.values():
+                        pinlist.append(pin)
+            elif netname:
+                for pin in self._pedb.pins:
+                    if pin.net_name == netname:
+                        pinlist.append(pin)
+            else:
+                self._logger.error("At least a component or a net name has to be provided")
+
+        return pinlist
 
     @pyaedt_function_handler()
     def get_pad_parameters(self, pin, layername, pad_type=0):
@@ -403,6 +470,55 @@ class EdbPadstacks(object):
         rot = padparams[5].ToDouble()
         return geom_type, parameters, offset_x, offset_y, rot
 
+    @pyaedt_function_handler
+    def set_all_antipad_value(self, value):
+        """Set all anti-pads from all pad-stack definition to the given value.
+
+        Parameters
+        ----------
+        value : float, str
+            anti-pad value
+
+        Returns
+        --------
+        bool
+            ``True`` when all succeed. ``False`` if one of anti-pads value failed to be assigned.
+        """
+        if self.padstacks:
+            for padstack in list(self.padstacks.values()):
+                cloned_padstack_data = self._edb.Definition.PadstackDefData(padstack.edb_padstack.GetData())
+                layers_name = cloned_padstack_data.GetLayerNames()
+                all_succeed = True
+                for layer in layers_name:
+                    geom_type, parameters, offset_x, offset_y, rot = self.get_pad_parameters(
+                        padstack.edb_padstack, layer, 1
+                    )
+                    if geom_type == 1:  # pragma no cover
+                        params = convert_py_list_to_net_list(
+                            [self._pedb.edb_value(value)] * len(parameters)
+                        )  # pragma no cover
+                        geom = self._edb.Definition.PadGeometryType.Circle
+                        offset_x = self._pedb.edb_value(offset_x)
+                        offset_y = self._pedb.edb_value(offset_y)
+                        rot = self._pedb.edb_value(rot)
+                        antipad = self._edb.Definition.PadType.AntiPad
+                        if cloned_padstack_data.SetPadParameters(
+                            layer, antipad, geom, params, offset_x, offset_y, rot
+                        ):  # pragma no cover
+                            self._logger.info(
+                                "Pad-stack definition {}, anti-pad on layer {}, has been set to {}".format(
+                                    padstack.edb_padstack.GetName(), layer, str(value)
+                                )
+                            )
+                        else:  # pragma no cover
+                            self._logger.error(
+                                "Failed to reassign anti-pad value {} on Pads-stack definition {},"
+                                " layer{}".format(str(value), padstack.edb_padstack.GetName(), layer)
+                            )
+                            all_succeed = False
+                padstack.edb_padstack.SetData(cloned_padstack_data)
+                return all_succeed
+
     @pyaedt_function_handler()
     def get_via_instance_from_net(self, net_list=None):
         """Get the list for Edb vias from net name list.
@@ -452,6 +568,7 @@ class EdbPadstacks(object):
         offset_x="0.0",
         offset_y="0.0",
         rotation="0.0",
+        has_hole=True,
     ):
         """Create a padstack.
 
@@ -485,6 +602,8 @@ class EdbPadstacks(object):
             Y offset of antipad. The default is ``"0.0"``.
         rotation : str, optional
             rotation of antipad. The default is ``"0.0"``.
+        has_hole : bool, optional
+            Whether this padstack has a hole.
         Returns
         -------
         str
@@ -498,7 +617,10 @@ class EdbPadstacks(object):
             padstackname = generate_unique_name("VIA")
         # assert not self.isreadonly, "Write Functions are not available within AEDT"
         padstackData = self._edb.Definition.PadstackDefData.Create()
-        ptype = self._edb.Definition.PadGeometryType.Circle
+        if has_hole:
+            ptype = self._edb.Definition.PadGeometryType.Circle
+        else:
+            ptype = self._edb.Definition.PadGeometryType.NoGeometry
         holparam = Array[type(holediam)]([holediam])
         value0 = self._get_edb_value("0.0")
         x_size = self._get_edb_value(x_size)
