@@ -1,7 +1,17 @@
 import sys
 import threading
+import warnings
 
-import numpy as np
+from pyaedt.generic.general_methods import is_ironpython
+
+if not is_ironpython:
+    try:
+        import numpy as np
+    except ImportError:
+        warnings.warn(
+            "The NumPy module is required to run some functionalities of PostProcess.\n"
+            "Install with \n\npip install numpy\n\nRequires CPython."
+        )
 
 
 class ThreadTrace(threading.Thread):
