@@ -1,7 +1,9 @@
 import os
 import sys
+import warnings
 
 from pyaedt.generic.general_methods import _retry_ntimes
+from pyaedt.generic.general_methods import generate_unique_name
 from pyaedt.generic.general_methods import pyaedt_function_handler
 from pyaedt.modeler.GeometryOperators import GeometryOperators
 from pyaedt.modeler.Object3d import Padstack
@@ -409,9 +411,9 @@ class Primitives3DLayout(object):
         dict[str, :class:`pyaedt.modeler.object3dlayout.Pins3DLayout`]
             Vias Dictionary.
         """
-        if self._vias:
-            return self._vias
         objs = self.modeler.oeditor.FindObjects("Type", "via")
+        if self._vias and len(objs) == len(self._vias):
+            return self._vias
         for obj in objs:
             self._vias[obj] = Pins3DLayout(self, obj, is_pin=False)
         return self._vias
@@ -524,7 +526,7 @@ class Primitives3DLayout(object):
 
         Returns
         -------
-        type
+        :class:`pyaedt.modeler.Object3d.Padstack`
             Padstack object if a padstack with this name does not already exist.
 
         """
@@ -593,8 +595,7 @@ class Primitives3DLayout(object):
                             lay = prop[i]
                             lay_name = lay[2]
                             lay_id = int(lay[4])
-                            if i != 1:
-                                self._padstacks[name].add_layer(lay_name)
+                            self._padstacks[name].add_layer(layername=lay_name, layer_id=lay_id)
                             self._padstacks[name].layers[lay_name].layername = lay_name
                             self._padstacks[name].layers[lay_name].pad = self._padstacks[name].add_hole(
                                 lay[6][1], list(lay[6][3]), lay[6][5], lay[6][7], lay[6][9]
@@ -623,8 +624,9 @@ class Primitives3DLayout(object):
         ----------
         netlist : str  or list, optional
             One or more nets to visualize. The default is ``None``.
+            If no nets are provided all the nets in the design will be selected.
         visible : bool, optional
-            Whether to make the selected nets visible. The
+            Whether to make the selected nets visible.
             The default value is ``False``.
 
         Returns
@@ -637,19 +639,45 @@ class Primitives3DLayout(object):
 
         >>> oEditor.SetNetVisible
         """
+        nets_dictionary = {}
         if not netlist:
             netlist = self.nets
-
-        if type(netlist) is str:
+        elif [x for x in netlist if x not in self.nets]:
+            self.logger.error("Selected net doesn't exist in current design.")
+            return False
+        if isinstance(netlist, str):
             netlist = [netlist]
+
+        if isinstance(visible, str):
+            if visible.lower() == "true":
+                visible = True
+            elif visible.lower() == "false":
+                visible = False
+            else:
+                self.logger.error("Provide a valid string value for visibility.")
+                return False
+        elif not isinstance(visible, bool):
+            self.logger.error("Provide a valid type value for visibility.")
+            return False
+
+        for net in self.nets:
+            if net not in netlist:
+                nets_dictionary[net] = not visible
+            else:
+                nets_dictionary[net] = visible
+
         args = ["NAME:Args"]
-        for net in netlist:
-            args.append("Name:=")
-            args.append(net)
-            args.append("Vis:=")
-            args.append(visible)
-        self.oeditor.SetNetVisible(args)
-        return True
+        try:
+            for key in nets_dictionary:
+                args.append("Name:=")
+                args.append(key)
+                args.append("Vis:=")
+                args.append(nets_dictionary[key])
+            self.oeditor.SetNetVisible(args)
+            return True
+        except:
+            self.logger.error("Couldn't change nets visibility.")
+            return False
 
     @pyaedt_function_handler()
     def create_via(
@@ -676,24 +704,23 @@ class Primitives3DLayout(object):
             Position on the Y axis. The default is ``0``.
         rotation : float, optional
             Angle rotation in degrees. The default is ``0``.
-        hole_diam :
-            Diameter of the hole. The default is ``None``, in which case
-            the override is disabled.
+        hole_diam : float, optional
+            Diameter of the hole. If ``None`` the default is ``1``,
+            in which case the override is disabled.
         top_layer : str, optional
-            Top layer. The default is ``None``.
+            Top layer. If ``None`` the first layer is taken.
         bot_layer : str, optional
-            Bottom layer. The default is ``None``.
+            Bottom layer. If ``None`` the last layer is taken.
         name : str, optional
-            Name of the via. The default is ``None``, in which case the
-            default name is assigned.
+            Name of the via. If ``None`` a random name is generated.
         netname : str, optional
-            Name of the net. The default is ``None``, in which case the
-            default name is assigned.
+            Name of the net. The default is ``None``, in which case no
+            name is assigned.
 
         Returns
         -------
-        str
-            Name of the via created when successful.
+        str or bool
+            Name of the via created when successful, ``False`` when failed.
 
         References
         ----------
@@ -706,37 +733,49 @@ class Primitives3DLayout(object):
         if not bot_layer:
             bot_layer = layers[len(layers) - 1]
         if not name:
-            name = _uname()
+            name = generate_unique_name("via")
         else:
             listnames = self.oeditor.FindObjects("Name", name)
             if listnames:
                 name = _uname(name)
-        arg = ["NAME:Contents"]
-        arg.append("name:="), arg.append(name)
-        arg.append("ReferencedPadstack:="), arg.append(padstack),
-        arg.append("vposition:="),
-        arg.append(["x:=", self.arg_with_dim(x), "y:=", self.arg_with_dim(y)])
-        arg.append("vrotation:="), arg.append([str(rotation) + "deg"])
-        if hole_diam:
-            arg.append("overrides hole:="), arg.append(True)
-            arg.append("hole diameter:="), arg.append([self.arg_with_dim(hole_diam)])
+        try:
+            arg = ["NAME:Contents"]
+            arg.append("name:="), arg.append(name)
+            arg.append("ReferencedPadstack:="), arg.append(padstack),
+            arg.append("vposition:="),
+            arg.append(["x:=", self.arg_with_dim(x), "y:=", self.arg_with_dim(y)])
+            arg.append("vrotation:="), arg.append([str(rotation) + "deg"])
+            if hole_diam:
+                arg.append("overrides hole:="), arg.append(True)
+                arg.append("hole diameter:="), arg.append([self.arg_with_dim(hole_diam)])
 
-        else:
-            arg.append("overrides hole:="), arg.append(False)
-            arg.append("hole diameter:="), arg.append([self.arg_with_dim(1)])
+            else:
+                arg.append("overrides hole:="), arg.append(False)
+                arg.append("hole diameter:="), arg.append([self.arg_with_dim(1)])
 
-        arg.append("Pin:="), arg.append(False)
-        arg.append("highest_layer:="), arg.append(top_layer)
-        arg.append("lowest_layer:="), arg.append(bot_layer)
-        self.oeditor.CreateVia(arg)
-        # self.objects[name] = Object3dlayout(self)
-        # self.objects[name].name = name
-        # if netname:
-        #     self.objects[name].set_net_name(netname)
-        return name
+            arg.append("Pin:="), arg.append(False)
+            arg.append("highest_layer:="), arg.append(top_layer)
+            arg.append("lowest_layer:="), arg.append(bot_layer)
+
+            self.oeditor.CreateVia(arg)
+            if netname:
+                self.oeditor.ChangeProperty(
+                    [
+                        "NAME:AllTabs",
+                        [
+                            "NAME:BaseElementTab",
+                            ["NAME:PropServers", name],
+                            ["NAME:ChangedProps", ["NAME:Net", "Value:=", netname]],
+                        ],
+                    ]
+                )
+            return name
+        except ValueError as e:
+            self.logger.error(str(e))
+            return False
 
     @pyaedt_function_handler()
-    def create_circle(self, layername, x, y, radius, name=None, netname=None):
+    def create_circle(self, layername, x, y, radius, name=None, net_name=None, **kwargs):
         """Create a circle on a layer.
 
         Parameters
@@ -752,7 +791,7 @@ class Primitives3DLayout(object):
         name : str, optional
             Name of the circle. The default is ``None``, in which case the
             default name is assigned.
-        netname : str, optional
+        net_name : str, optional
             Name of the net. The default is ``None``, in which case the
             default name is assigned.
 
@@ -766,6 +805,12 @@ class Primitives3DLayout(object):
 
         >>> oEditor.CreateCircle
         """
+        if "netname" in kwargs:
+            warnings.warn(
+                "`netname` is deprecated. Use `net_name` instead.",
+                DeprecationWarning,
+            )
+            net_name = kwargs["netname"]
         if not name:
             name = _uname()
         else:
@@ -783,11 +828,18 @@ class Primitives3DLayout(object):
         vArg2.append("r:="), vArg2.append(self.arg_with_dim(radius))
         vArg1.append(vArg2)
         self.oeditor.CreateCircle(vArg1)
-        self._circles[name] = Circle3dLayout(self, name, False)
+        primitive = Circle3dLayout(self, name, False)
+        self._circles[name] = primitive
+
+        if net_name:
+            primitive.change_property(property_val=["NAME:Net", "Value:=", net_name])
+
         return name
 
     @pyaedt_function_handler()
-    def create_rectangle(self, layername, origin, dimensions, corner_radius=0, angle=0, name=None, netname=None):
+    def create_rectangle(
+        self, layername, origin, dimensions, corner_radius=0, angle=0, name=None, net_name=None, **kwargs
+    ):
         """Create a rectangle on a layer.
 
         Parameters
@@ -795,16 +847,16 @@ class Primitives3DLayout(object):
         layername : str
             Name of the layer.
         origin : list
-            Origin of the coordinate system in a list of ``[x, y, z]`` coordinates.
+            Origin of the coordinate system in a list of ``[x, y]`` coordinates.
         dimensions : list
-            Dimensions for the box in a list of ``[x, y, z]`` coordinates.
+            Dimensions for the box in a list of ``[x, y]`` coordinates.
         corner_radius : float, optional
         angle : float, optional
             Angle rotation in degrees. The default is ``0``.
         name : str, optional
             Name of the rectangle. The default is ``None``, in which case the
             default name is assigned.
-        netname : str, optional
+        net_name : str, optional
             Name of the net. The default is ``None``, in which case the
             default name is assigned.
 
@@ -818,7 +870,12 @@ class Primitives3DLayout(object):
 
         >>> oEditor.CreateRectangle
         """
-
+        if "netname" in kwargs:
+            warnings.warn(
+                "`netname` is deprecated. Use `net_name` instead.",
+                DeprecationWarning,
+            )
+            net_name = kwargs["netname"]
         if not name:
             name = _uname()
         else:
@@ -839,11 +896,18 @@ class Primitives3DLayout(object):
         vArg2.append("ang="), vArg2.append(self.arg_with_dim(angle))
         vArg1.append(vArg2)
         self.oeditor.CreateRectangle(vArg1)
-        self._rectangles[name] = Rect3dLayout(self, name, False)
+        primitive = Rect3dLayout(self, name, False)
+        self._rectangles[name] = primitive
+
+        if net_name:
+            primitive.change_property(property_val=["NAME:Net", "Value:=", net_name])
+
         return name
 
     @pyaedt_function_handler()
-    def create_line(self, layername, center_line_list, lw=1, start_style=0, end_style=0, name=None, netname=None):
+    def create_line(
+        self, layername, center_line_list, lw=1, start_style=0, end_style=0, name=None, net_name=None, **kwargs
+    ):
         """Create a line based on a list of points.
 
         Parameters
@@ -851,7 +915,7 @@ class Primitives3DLayout(object):
         layername : str
             Name of the layer to create the line on.
         center_line_list : list
-            List of centerline coordinates in the form of ``[x, y, z]``.
+            List of centerline coordinates in the form of ``[x, y]``.
         lw : float, optional
             Line width. The default is ``1``.
         start_style :
@@ -868,7 +932,7 @@ class Primitives3DLayout(object):
         name : str, optional
             Name  of the line. The default is ``None``, in which case the
             default name is assigned.
-        netname : str, optional
+        net_name : str, optional
             Name of the net. The default is ``None``, in which case the
             default name is assigned.
 
@@ -882,6 +946,12 @@ class Primitives3DLayout(object):
 
         >>> oEditor.CreateLine
         """
+        if "netname" in kwargs:
+            warnings.warn(
+                "`netname` is deprecated. Use `net_name` instead.",
+                DeprecationWarning,
+            )
+            net_name = kwargs["netname"]
         if not name:
             name = _uname()
         else:
@@ -912,7 +982,12 @@ class Primitives3DLayout(object):
             arg2.append(a[1])
         arg.append(arg2)
         self.oeditor.CreateLine(arg)
-        self._lines[name] = Line3dLayout(self, name, False)
+        primitive = Line3dLayout(self, name, False)
+        self._lines[name] = primitive
+
+        if net_name:
+            primitive.change_property(property_val=["NAME:Net", "Value:=", net_name])
+
         return name
 
     @pyaedt_function_handler()
@@ -1043,3 +1118,55 @@ class Primitives3DLayout(object):
         comp = ComponentsSubCircuit3DLayout(self, comp_name.split(";")[-1])
         self.components_3d[comp_name.split(";")[-1]] = comp
         return comp  #
+
+    def create_text(self, text, position, angle=0, font_size=12):
+        """Create a text primitive object.
+
+        Parameters
+        ----------
+        text : str
+            Name for the text primitive object.
+        position : list
+            Position of the text.
+        angle : float, optional
+            Angle of the text. The default value is ``0``.
+        font_size : int, optional
+            Font size. The default value is ``12``.
+
+        Returns
+        -------
+        str
+            Name of the text primitive.
+        """
+        name = _uname("text_")
+        args = [
+            "NAME:Contents",
+            "textGeometry:=",
+            [
+                "Name:=",
+                name,
+                "LayerName:=",
+                "Postprocessing",
+                "x:=",
+                position[0],
+                "y:=",
+                position[1],
+                "ang:=",
+                angle,
+                "isPlot:=",
+                False,
+                "font:=",
+                "Arial",
+                "size:=",
+                font_size,
+                "weight:=",
+                3,
+                "just:=",
+                4,
+                "mirror:=",
+                False,
+                "text:=",
+                text,
+            ],
+        ]
+        return self.modeler.oeditor.CreateText(args)
